# Welcome to django-qa
## A Simple Q&A App using Python Django

[django-qa](http://swappsco.github.io/django-qa/) is a fork from [Simple-Q-A-App-using-Python-Django](http://arjunkomath.github.io/Simple-Q-A-App-using-Python-Django) aimed to create a pluggable package than allows to implement a StackOverflow-like forum site for your Django web project.

The development of this package is kindly supported by [SWAPPS](https://www.swapps.co/) and constantly developed by it's colaborators. Feel free to use it, add some issues if you find bugs or think of a really cool feature, even clone it and generate a pull requests to incorporate those cool features made by yourself; and if you have special requirements, [drop us a few lines](https://www.swapps.co/) and perhaps we can help you out too.

## This is how it looks
## Screenshots

Home Page:
<img src="https://raw.githubusercontent.com/swappsco/django-qa/master/qa/static/qa/qa_index.jpeg" />

QA Page:
<img src="https://raw.githubusercontent.com/swappsco/django-qa/master/qa/static/qa/qa_page.jpeg" />

This django package is provided under the the MIT license, for more information please refer to the [license](https://github.com/swappsco/django-qa/blob/master/LICENSE.md) file.
